package com.huiju.estateagents.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaNews;
import com.huiju.estateagents.entity.TaShareActivity;
import com.huiju.estateagents.service.ITaShareActivityService;
import io.swagger.models.auth.In;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 拼团活动表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-17
 */
@RestController
@RequestMapping("/api")
public class TaShareActivityController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShareActivityController.class);

    @Autowired
    public ITaShareActivityService iTaShareActivityService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taShareActivity/list",method= RequestMethod.GET)
    public ResponseBean taShareActivityList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                            @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                            @RequestParam(value ="buildingId",required = false) String buildingId,
                                            @RequestParam(value ="activityName",required = false) String activityName,
                                            @RequestParam(value ="status",required = false) String status,
                                            HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaShareActivityService.getList(pageNum, pageSize, buildingId, activityName, status, null, null, getOrgId(request));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param parameter 实体对象json格式
     * @return
     */
    @RequestMapping(value="/admin/taShareActivity",method= RequestMethod.POST)
    public ResponseBean taShareActivityAdd(@RequestBody String parameter, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            TaShareActivity taShareActivity = JSONObject.parseObject(parameter, TaShareActivity.class);
            taShareActivity.setOrgId(getOrgId(request));
            taShareActivity.setStatus(0);
            taShareActivity.setSort(false);
            taShareActivity.setWeight(0);
            if (iTaShareActivityService.save(taShareActivity)){
                responseBean.addSuccess(taShareActivity);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/taShareActivity/{id}", method= RequestMethod.DELETE)
    public ResponseBean taShareActivityDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaShareActivityService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param  parameter 实体对象json
     * @return
     */
    @RequestMapping(value="/admin/taShareActivity/update",method= RequestMethod.PUT)
    public ResponseBean taShareActivityUpdate(@RequestBody String parameter){
        ResponseBean responseBean = new ResponseBean();
        try {
            TaShareActivity taShareActivity = JSONObject.parseObject(parameter, TaShareActivity.class);
            if (iTaShareActivityService.updateById(taShareActivity)){
                responseBean.addSuccess(taShareActivity);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taShareActivity/{id}",method= RequestMethod.GET)
    public ResponseBean taShareActivityGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaShareActivityService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id结束拼团活动
     * @param id
     * @return
     */
    @RequestMapping(value="/admin/taShareActivity/finish/{id}",method= RequestMethod.PUT)
    public ResponseBean finishShareActicity(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            TaShareActivity taShareActivity = new TaShareActivity();
            taShareActivity.setStatus(2);
            taShareActivity.setGroupActicityId(id);
            if (iTaShareActivityService.updateById(taShareActivity)){
                responseBean.addSuccess(taShareActivity);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareActivityUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 置顶活动，首页推荐
     * @param taShareActivity
     * @param request
     * @return
     */
    @RequestMapping(value = "/admin/taShareActivity/weight" ,method =RequestMethod.PUT)
    public  ResponseBean buildingDynamicWeight(@RequestBody TaShareActivity taShareActivity, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        if (taShareActivity.getWeight() != null){
            taShareActivity.setWeight(taShareActivity.getWeight() == 0 ? 1 : 0);
        }
        if (taShareActivity.getSort() != null){
            taShareActivity.setSort(taShareActivity.getSort() == true ? false : true);
        }

        QueryWrapper<TaNews> newsQueryWrapper = new QueryWrapper<>();
        newsQueryWrapper.eq("group_acticity_id", taShareActivity.getGroupActicityId());
        if (iTaShareActivityService.updateById(taShareActivity)){
            responseBean.addSuccess("成功");
        }else {
            responseBean.addError("失败");
        }
        return responseBean;
    }

}
